# Smart grid

<!--toc:start-->
- [Smart grid](#smart-grid)
  - [Not smart grid](#not-smart-grid)
  - [Smart grid](#smart-grid)
  - [Reason](#reason)
  - [Implementation](#implementation)
    - [Optimizing the electric grid](#optimizing-the-electric-grid)
    - [Big data and smart grid:](#big-data-and-smart-grid)
    - [Load shifting / Peak shaving](#load-shifting-peak-shaving)
    - [Other considerations for smart grid](#other-considerations-for-smart-grid)
      - [Privacy concern](#privacy-concern)
      - [Flexibility, and comfort of saving electricity](#flexibility-and-comfort-of-saving-electricity)
    - [Use cases : Household power usage](#use-cases-household-power-usage)
    - [Example solutions](#example-solutions)
<!--toc:end-->

## Not smart grid

- Electric grid, production, delivery and consumption has to occur
  instantaneously and in perfect balance
- Reason for not smart:
    - Frequency matches generation and demand
    - Voltage is generator and transformer
    - Current is the upper limit of devices and have to provide spare capacity

## Smart grid

- Features:
    - Cost efficiency
    - Economically efficient, sustainable
    - Quality
    - Security
    - Safety
- How to
    - Integrate the power infrastructure with Information and Communication
      Infrastructure
- Problems present:
    - Energy Security
    - Energy Sustainability
    - Energy equity

## Reason

- The UK Government pledge
    - Reduce carbon emission by 68% by 2030
    - more , 2035
    - net zero by 2050
- Renewable with the traditional grid: power flow is less predictable
- Renewable with changing landscape: user demand is more challenging to predict
- Just In Time Delivery
    - Dealing with excessive energy
        - Store
        - Sell
        - Run power station
        - Problem: Excess power may damage device or parts of grid
    - Not enough energy
        - Use stored energy
        - Hydro power
        - Buy
        - Problem: risk of black out
- This means we should use smart grid:
    - ![smart grid diagram](./assets/3-smart-grid-diagram.webp)
    - ![another diagram](./assets/3-smart-grid-diagram-2.webp)

## Implementation

### Optimizing the electric grid

- Continuous: Accurate forecast of demand and production to increase cost
  efficiency, and resilience of electricity provision
- Predictive: Informed planning of renewable energy and storage to reach net
  zero
- Integration and collaboration: integrate with other infrastructures for
  efficiency and collaborative intelligence

### Big data and smart grid:

- Sources:
    - ![smart grid big data sources](./assets/3-smart-grid-big-data-sources.webp)
- Characteristics of big data:
    - Volume: Amount of data:
        - Likely terabytes in size
        - Stores transactions
        - In form of stream or batch
    - Variety: Lots of data types:
        - Structured or unstructured
        - Multi-factor, and probabilistic
    - Velocity: Speed of data flow:
        - Real time
        - Near real time
        - In stream or batch
    - Value: Extracting insights
        - For business
        - For revenue streams
        - Has operational value
    - Uncertain: Data uncertainty
        - Authenticity on data
        - Origin of data
        - Availability of data
        - Accountability
- Analytics: the more sophistication, the more value.
    - Hindsight: descriptive of what happened
    - Insight: diagnostic of current situation
    - Foresight: Prediction, and perspective
    - ![analytics diagram](./assets/3-smart-grid-analytics.webp)
- Example:
    - ![Example](./assets/3-analytics-examples.webp)

### Load shifting / Peak shaving

- To flatten the instantaneous energy demand, by load shifting and peak shaving
    - Using the peak and off-peak electricity tariff (tax)

### Other considerations for smart grid

#### Privacy concern
- The more fine grained data is, the more risk in privacy

#### Flexibility, and comfort of saving electricity

- Gadgets owned:
    - TV: least beneficial
    - EV charger: essential to EV owners
- Work from home vs. Work from office

### Use cases : Household power usage
- Usage differs per number of occupants
- Try to apply load shifting for each house hold
- Predcit:
    - Timing for high / low energy usage per day
    - Same in a week and a year
    - Most energy consumption during peak
    - Can you estimate when they wake up or go to sleep
    - predict if work from home or out
- Design dual tariff to shift load
    - Time of day to trigger
    - If it's the same every day of week
    - Every month of year

### Example solutions

- Digital twin: has privacy concern
- Adaptive dual tariff: low rate before, and high rate after threshold
- Reinforcement learning: to learn about the environment
- These results in smoothed electric curve
